<?php

namespace Drupal\menu_cache\Hook;

use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Security\TrustedCallbackInterface;

class BlockHooks implements TrustedCallbackInterface {

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['preRenderOptimizeTags'];
  }

  #[Hook('block_view_system_menu_block_alter')]
  public function menuBlockViewAlter(array &$build, BlockPluginInterface $block): void {
    // If the current user is anonymous, register a pre render callback
    // to optimize the cache tags.
    if (\Drupal::currentUser()->isAnonymous()) {
      //$build['#pre_render'][] = [static::class, 'preRenderOptimizeTags'];
    }
  }

  /**
   * Pre Render callback to remove node cache tags.
   */
  public static function preRenderOptimizeTags($build): array {
    if (!empty($build['content']['#cache']['tags'])) {
      $build['content']['#cache']['tags'] = array_filter($build['content']['#cache']['tags'], function ($tag) {
        return !str_starts_with($tag, 'node:');
      });
    }

    return $build;
  }

}
