<?php

namespace Drupal\menu_cache\Hook;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Menu\MenuTreeStorageInterface;
use Drupal\node\NodeInterface;

class NodeHooks {

  public function __construct(protected MenuTreeStorageInterface $treeStorage) {

  }

  #[Hook('node_update')]
  public function nodeUpdate(NodeInterface $node): void {
    // @phpstan-ignore-next-line
    $origin = method_exists($node, 'getOriginal') ? $node->getOriginal() : $node->original;

    // If the publication status of the node changes, look for menu links
    // and invalidate the corresponding menus.
    if ($node->isDefaultRevision() && $origin->isPublished() != $node->isPublished()) {
      // @todo only support menu links entities, query by serialized array
      //   is awkward.
      $links = $this->treeStorage->loadByProperties([
        'route_name' => 'entity.node.canonical',
        'route_parameters' => serialize(['node' => $node->id()]),
      ]);
      $cache_tags = [];
      foreach ($links as $link) {
        $cache_tags[] = 'config:system.menu.' . $link['menu_name'];
      }
      Cache::invalidateTags($cache_tags);
    }
  }

}
